@@ -83,9 +83,18 @@ ConnectionEditor::ConnectionEditor(QWidget* parent, Qt::WindowFlags flags)
     initializeConnections();
     initializeMenu();
 
-    KConfigGroup grp(KSharedConfig::openConfig(), "ConnectionsWidget");
+    KSharedConfigPtr config = KSharedConfig::openConfig();
+    KConfigGroup grp(config, "ConnectionsWidget");
     m_editor->connectionsWidget->header()->restoreState(grp.readEntry<QByteArray>("state", QByteArray()));
 
+    KConfigGroup grp2(config, "General");
+    if (grp2.isValid()) {
+        if (grp2.readEntry("FirstStart", true)) {
+            importSecretsFromPlainTextFiles();
+        }
+        grp2.writeEntry("FirstStart", false);
+    }
+
     connect(m_editor->connectionsWidget->selectionModel(), &QItemSelectionModel::currentChanged, this, &ConnectionEditor::slotSelectionChanged);
     connect(m_editor->connectionsWidget, &QTreeView::doubleClicked, this, &ConnectionEditor::slotItemDoubleClicked);
     connect(m_editor->connectionsWidget, &QTreeView::customContextMenuRequested, this, &ConnectionEditor::slotContextMenuRequested);
@@ -94,17 +103,6 @@ ConnectionEditor::ConnectionEditor(QWidget* parent, Qt::WindowFlags flags)
     connect(NetworkManager::settingsNotifier(), SIGNAL(connectionAdded(QString)),
             SLOT(connectionAdded(QString)));
 
-    KConfig config("kde5-nm-connection-editor");
-    KConfigGroup generalGroup = config.group("General");
-
-    if (generalGroup.isValid()) {
-        if (generalGroup.readEntry("FirstStart", true)) {
-            importSecretsFromPlainTextFiles();
-        }
-
-        generalGroup.writeEntry("FirstStart", false);
-    }
-
     QLoggingCategory::setFilterRules(QStringLiteral("plasma-nm.debug = false"));
     QLoggingCategory::setFilterRules(QStringLiteral("plasma-nm.warning = true"));
 }
@@ -181,7 +179,7 @@ void ConnectionEditor::initializeMenu()
     m_menu->menu()->addSection(i18n("VPN"));
 
     const KService::List services = KServiceTypeTrader::self()->query("PlasmaNetworkManagement/VpnUiPlugin");
-    Q_FOREACH(const KService::Ptr & service, services) {
+    Q_FOREACH (const KService::Ptr & service, services) {
         qCDebug(PLASMA_NM) << "Found VPN plugin" << service->name() << ", type:" << service->property("X-NetworkManager-Services", QVariant::String).toString();
 
         action = new QAction(service->name(), this);
@@ -234,7 +232,6 @@ void ConnectionEditor::initializeMenu()
 
 void ConnectionEditor::addConnection(QAction* action)
 {
-    NetworkManager::ConnectionSettings::Ptr connectionSettings;
     NetworkManager::ConnectionSettings::ConnectionType type = static_cast<NetworkManager::ConnectionSettings::ConnectionType>(action->data().toUInt());
     const QString vpnType = action->property("type").toString();
 
@@ -242,40 +239,51 @@ void ConnectionEditor::addConnection(QAction* action)
 
     if (type == NetworkManager::ConnectionSettings::Gsm) { // launch the mobile broadband wizard, both gsm/cdma
 #if WITH_MODEMMANAGER_SUPPORT
-        QWeakPointer<MobileConnectionWizard> wizard = new MobileConnectionWizard(NetworkManager::ConnectionSettings::Unknown, this);
-        if (wizard.data()->exec() == QDialog::Accepted && wizard.data()->getError() == MobileProviders::Success) {
-            qCDebug(PLASMA_NM) << "Mobile broadband wizard finished:" << wizard.data()->type() << wizard.data()->args();
+        QPointer<MobileConnectionWizard> wizard = new MobileConnectionWizard(NetworkManager::ConnectionSettings::Unknown, this);
+        connect(wizard.data(), &MobileConnectionWizard::accepted,
+                [wizard, this] () {
+                    if (wizard->getError() == MobileProviders::Success) {
+                        qCDebug(PLASMA_NM) << "Mobile broadband wizard finished:" << wizard->type() << wizard->args();
 
-            if (wizard.data()->args().count() == 2) {
-                QVariantMap tmp = qdbus_cast<QVariantMap>(wizard.data()->args().value(1));
+                        if (wizard->args().count() == 2) {
+                            QVariantMap tmp = qdbus_cast<QVariantMap>(wizard->args().value(1));
 
-#if 0 // network IDs are not used yet and seem to break the setting
-        if (args.count() == 3) { // gsm specific
-            QStringList networkIds = args.value(1).toStringList();
-            if (!networkIds.isEmpty())
-                tmp.insert("network-id", networkIds.first());
-        }
+#if 0                       // network IDs are not used yet and seem to break the setting
+                            if (args.count() == 3) { // gsm specific
+                            QStringList networkIds = args.value(1).toStringList();
+                            if (!networkIds.isEmpty())
+                                tmp.insert("network-id", networkIds.first());
+                            }
 #endif
-                connectionSettings = NetworkManager::ConnectionSettings::Ptr(new NetworkManager::ConnectionSettings(wizard.data()->type()));
-                connectionSettings->setId(wizard.data()->args().value(0).toString());
-                if (wizard.data()->type() == NetworkManager::ConnectionSettings::Gsm) {
-                    connectionSettings->setting(NetworkManager::Setting::Gsm)->fromMap(tmp);
-                } else if (wizard.data()->type() == NetworkManager::ConnectionSettings::Cdma) {
-                    connectionSettings->setting(NetworkManager::Setting::Cdma)->fromMap(tmp);
-                } else {
-                    qCWarning(PLASMA_NM) << Q_FUNC_INFO << "Unhandled setting type";
-                }
-            } else {
-                qCWarning(PLASMA_NM) << Q_FUNC_INFO << "Unexpected number of args to parse";
-            }
-        }
-
-        if (wizard) {
-            wizard.data()->deleteLater();
-        }
-
+                            NetworkManager::ConnectionSettings::Ptr connectionSettings;
+                            connectionSettings = NetworkManager::ConnectionSettings::Ptr(new NetworkManager::ConnectionSettings(wizard->type()));
+                            connectionSettings->setId(wizard->args().value(0).toString());
+                            if (wizard->type() == NetworkManager::ConnectionSettings::Gsm) {
+                                connectionSettings->setting(NetworkManager::Setting::Gsm)->fromMap(tmp);
+                            } else if (wizard->type() == NetworkManager::ConnectionSettings::Cdma) {
+                                connectionSettings->setting(NetworkManager::Setting::Cdma)->fromMap(tmp);
+                            } else {
+                                qCWarning(PLASMA_NM) << Q_FUNC_INFO << "Unhandled setting type";
+                            }
+                            // Generate new UUID
+                            connectionSettings->setUuid(NetworkManager::ConnectionSettings::createNewUuid());
+                            addConnection(connectionSettings);
+                        } else {
+                            qCWarning(PLASMA_NM) << Q_FUNC_INFO << "Unexpected number of args to parse";
+                        }
+                    }
+                });
+        connect(wizard.data(), &MobileConnectionWizard::finished,
+                [wizard] () {
+                    if (wizard) {
+                        wizard->deleteLater();
+                    }
+                });
+        wizard->setModal(true);
+        wizard->show();
 #endif
     } else {
+        NetworkManager::ConnectionSettings::Ptr connectionSettings;
         connectionSettings = NetworkManager::ConnectionSettings::Ptr(new NetworkManager::ConnectionSettings(type));
 
         if (type == NetworkManager::ConnectionSettings::Vpn) {
@@ -292,7 +300,7 @@ void ConnectionEditor::addConnection(QAction* action)
                     wifiSetting->setMode(NetworkManager::WirelessSetting::Adhoc);
                     wifiSetting->setSsid(i18n("my_shared_connection").toUtf8());
 
-                    Q_FOREACH(const NetworkManager::Device::Ptr & device, NetworkManager::networkInterfaces()) {
+                    Q_FOREACH (const NetworkManager::Device::Ptr & device, NetworkManager::networkInterfaces()) {
                         if (device->type() == NetworkManager::Device::Wifi) {
                             NetworkManager::WirelessDevice::Ptr wifiDev = device.objectCast<NetworkManager::WirelessDevice>();
                             if (wifiDev) {
@@ -310,30 +318,28 @@ void ConnectionEditor::addConnection(QAction* action)
                 connectionSettings->setAutoconnect(false);
             }
         }
+        // Generate new UUID
+        connectionSettings->setUuid(NetworkManager::ConnectionSettings::createNewUuid());
+        addConnection(connectionSettings);
     }
+}
 
-    // In case that mobile broadband wizard has not been finished
-    if (!connectionSettings) {
-        return;
-    }
-
-    // Generate new UUID
-    connectionSettings->setUuid(NetworkManager::ConnectionSettings::createNewUuid());
-
+void ConnectionEditor::addConnection(const NetworkManager::ConnectionSettings::Ptr& connectionSettings)
+{
     QPointer<ConnectionDetailEditor> editor = new ConnectionDetailEditor(connectionSettings, true);
-
-    if (editor->exec() == QDialog::Accepted) {
-        if (type == NetworkManager::ConnectionSettings::Vpn) {
-            qCDebug(PLASMA_NM) << "Adding new connection of type " << vpnType;
-        } else {
-            qCDebug(PLASMA_NM) << "Adding new connection of type " << NetworkManager::ConnectionSettings::typeAsString(type);
-        }
-        m_handler->addConnection(editor->setting());
-    }
-
-    if (editor) {
-        editor->deleteLater();
-    }
+    connect(editor.data(), &ConnectionDetailEditor::accepted,
+            [connectionSettings, editor, this] () {
+                qCDebug(PLASMA_NM) << "Adding new connection of type " << NetworkManager::ConnectionSettings::typeAsString(connectionSettings->connectionType());
+                m_handler->addConnection(editor->setting());
+            });
+    connect(editor.data(), &ConnectionDetailEditor::finished,
+            [editor] () {
+                if (editor) {
+                    editor->deleteLater();
+                }
+            });
+    editor->setModal(true);
+    editor->show();
 }
 
 void ConnectionEditor::connectionAdded(const QString& connection)
@@ -437,7 +443,7 @@ void ConnectionEditor::removeConnection()
     if (KMessageBox::questionYesNo(this, i18n("Do you want to remove the connection '%1'?", connection->name()), i18n("Remove Connection"), KStandardGuiItem::remove(),
                                    KStandardGuiItem::no(), QString(), KMessageBox::Dangerous)
             == KMessageBox::Yes) {
-        Q_FOREACH(const NetworkManager::Connection::Ptr &con, NetworkManager::listConnections()) {
+        Q_FOREACH (const NetworkManager::Connection::Ptr &con, NetworkManager::listConnections()) {
             NetworkManager::ConnectionSettings::Ptr settings = con->settings();
             if (settings->master() == connection->uuid()) {
                 m_handler->removeConnection(con->path());
@@ -471,7 +477,7 @@ void ConnectionEditor::slotSelectionChanged(const QModelIndex &index, const QMod
         return;
     }
 
-    // qCDebug(PLASMA_NM) << "Clicked item" << index.data(NetworkModel::UuidRole).toString();
+    //qCDebug(PLASMA_NM) << "Clicked item" << index.data(NetworkModel::UuidRole).toString();
 
     if (index.parent().isValid()) { // category
         actionCollection()->action("connect_connection")->setEnabled(false);
@@ -511,14 +517,18 @@ void ConnectionEditor::slotItemDoubleClicked(const QModelIndex &index)
     NetworkManager::Connection::Ptr connection = NetworkManager::findConnectionByUuid(index.data(NetworkModel::UuidRole).toString());
 
     QPointer<ConnectionDetailEditor> editor = new ConnectionDetailEditor(connection->settings(), false);
-
-    if (editor->exec() == QDialog::Accepted) {
-        m_handler->updateConnection(connection, editor->setting());
-    }
-
-    if (editor) {
-        editor->deleteLater();
-    }
+    connect(editor.data(), &ConnectionDetailEditor::accepted,
+            [editor, connection, this] () {
+                m_handler->updateConnection(connection, editor->setting());
+            });
+    connect(editor.data(), &ConnectionDetailEditor::finished,
+            [editor] () {
+                if (editor) {
+                    editor->deleteLater();
+                }
+            });
+    editor->setModal(true);
+    editor->show();
 }
 
 void ConnectionEditor::importSecretsFromPlainTextFiles()
@@ -527,9 +537,9 @@ void ConnectionEditor::importSecretsFromPlainTextFiles()
     QDir dir(secretsDirectory);
     if (dir.exists() && !dir.entryList(QDir::Files).isEmpty()) {
         QMap<QString, QMap<QString, QString > > resultingMap;
-        Q_FOREACH(const QString & file, dir.entryList(QDir::Files)) {
+        Q_FOREACH (const QString & file, dir.entryList(QDir::Files)) {
             KConfig config(secretsDirectory % file, KConfig::SimpleConfig);
-            Q_FOREACH(const QString & groupName, config.groupList()) {
+            Q_FOREACH (const QString & groupName, config.groupList()) {
                 KConfigGroup group = config.group(groupName);
                 QMap<QString, QString> map = group.entryMap();
                 if (!map.isEmpty()) {
@@ -560,7 +570,7 @@ void ConnectionEditor::storeSecrets(const QMap< QString, QMap< QString, QString
 
         if (wallet->hasFolder(folderName) && wallet->setFolder(folderName)) {
             int count = 0;
-            Q_FOREACH(const QString & entry, map.keys()) {
+            Q_FOREACH (const QString & entry, map.keys()) {
                 QString connectionUuid = entry.split(';').first();
                 connectionUuid.replace('{',"").replace('}',"");
                 NetworkManager::Connection::Ptr connection = NetworkManager::findConnectionByUuid(connectionUuid);
@@ -579,7 +589,7 @@ void ConnectionEditor::importVpn()
     // get the list of supported extensions
     const KService::List services = KServiceTypeTrader::self()->query("PlasmaNetworkManagement/VpnUiPlugin");
     QString extensions;
-    Q_FOREACH(const KService::Ptr &service, services) {
+    Q_FOREACH (const KService::Ptr &service, services) {
         VpnUiPlugin * vpnPlugin = service->createInstance<VpnUiPlugin>(this);
         if (vpnPlugin) {
             extensions += vpnPlugin->supportedFileExtensions() % QStringLiteral(" ");
@@ -593,7 +603,7 @@ void ConnectionEditor::importVpn()
         const QString ext = QStringLiteral("*.") % fi.suffix();
         qCDebug(PLASMA_NM) << "Importing VPN connection " << filename << "extension:" << ext;
 
-        Q_FOREACH(const KService::Ptr &service, services) {
+        Q_FOREACH (const KService::Ptr &service, services) {
             VpnUiPlugin * vpnPlugin = service->createInstance<VpnUiPlugin>(this);
             if (vpnPlugin && vpnPlugin->supportedFileExtensions().contains(ext)) {
                 qCDebug(PLASMA_NM) << "Found VPN plugin" << service->name() << ", type:" << service->property("X-NetworkManager-Services", QVariant::String).toString();
