@@ -176,18 +176,22 @@ void BondWidget::addBond(QAction *action)
     connectionSettings->setAutoconnect(false);
 
     QPointer<ConnectionDetailEditor> bondEditor = new ConnectionDetailEditor(connectionSettings, true);
-
-    if (bondEditor->exec() == QDialog::Accepted) {
-        qCDebug(PLASMA_NM) << "Saving slave connection";
-        // qCDebug(PLASMA_NM) << bondEditor->setting();
-        QDBusPendingReply<QDBusObjectPath> reply = NetworkManager::addConnection(bondEditor->setting());
-        QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(reply, this);
-        connect(watcher, &QDBusPendingCallWatcher::finished, this, &BondWidget::bondAddComplete);
-    }
-
-    if (bondEditor) {
-        bondEditor->deleteLater();
-    }
+    connect(bondEditor.data(), &ConnectionDetailEditor::accepted,
+            [bondEditor, this] () {
+                qCDebug(PLASMA_NM) << "Saving slave connection";
+                // qCDebug(PLASMA_NM) << bondEditor->setting();
+                QDBusPendingReply<QDBusObjectPath> reply = NetworkManager::addConnection(bondEditor->setting());
+                QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(reply, this);
+                connect(watcher, &QDBusPendingCallWatcher::finished, this, &BondWidget::bondAddComplete);
+            });
+    connect(bondEditor.data(), &ConnectionDetailEditor::finished,
+            [bondEditor] () {
+                if (bondEditor) {
+                    bondEditor->deleteLater();
+                }
+            });
+    bondEditor->setModal(true);
+    bondEditor->show();
 }
 
 void BondWidget::currentBondChanged(QListWidgetItem *current, QListWidgetItem *previous)
@@ -228,14 +232,19 @@ void BondWidget::editBond()
     if (connection) {
         // qCDebug(PLASMA_NM) << "Editing bonded connection" << currentItem->text() << uuid;
         QPointer<ConnectionDetailEditor> bondEditor = new ConnectionDetailEditor(connection->settings(), this);
-        if (bondEditor->exec() == QDialog::Accepted) {
-            connection->update(bondEditor->setting());
-            connect(connection.data(), SIGNAL(updated()), this, SLOT(populateBonds()));
-        }
-
-        if (bondEditor) {
-            bondEditor->deleteLater();
-        }
+        connect(bondEditor.data(), &ConnectionDetailEditor::accepted,
+                [connection, bondEditor, this] () {
+                    connection->update(bondEditor->setting());
+                    connect(connection.data(), SIGNAL(updated()), this, SLOT(populateBonds()));
+                });
+        connect(bondEditor.data(), &ConnectionDetailEditor::finished,
+                [bondEditor] () {
+                    if (bondEditor) {
+                        bondEditor->deleteLater();
+                    }
+                });
+        bondEditor->setModal(true);
+        bondEditor->show();
     }
 }
 
@@ -264,7 +273,7 @@ void BondWidget::populateBonds()
 {
     m_ui->bonds->clear();
 
-    Q_FOREACH(const NetworkManager::Connection::Ptr &connection, NetworkManager::listConnections()) {
+    Q_FOREACH (const NetworkManager::Connection::Ptr &connection, NetworkManager::listConnections()) {
         NetworkManager::ConnectionSettings::Ptr settings = connection->settings();
         if (settings->master() == m_uuid && settings->slaveType() == type()) {
             const QString label = QString("%1 (%2)").arg(connection->name()).arg(connection->settings()->typeAsString(connection->settings()->connectionType()));
@@ -282,7 +291,7 @@ bool BondWidget::isValid() const
             return false;
         }
 
-        Q_FOREACH(const QString & ip, ipAddresses) {
+        Q_FOREACH (const QString & ip, ipAddresses) {
             QHostAddress ipAddress(ip);
             if (ipAddress.isNull()) {
                 return false;
