@@ -58,8 +58,17 @@ ConnectionWidget::ConnectionWidget(const NetworkManager::ConnectionSettings::Ptr
 
     connect(m_widget->autoconnectVpn, SIGNAL(toggled(bool)), SLOT(autoVpnToggled(bool)));
 
-    if (settings)
+    if (NetworkManager::compareVersion(QLatin1String("1.0.0")) >= 0) {
+        m_widget->prioritySpin->setEnabled(true);
+        m_widget->nmVersionWarning->setVisible(false);
+    } else {
+        m_widget->prioritySpin->setEnabled(false);
+        m_widget->nmVersionWarning->setVisible(true);
+    }
+
+    if (settings) {
         loadConfig(settings);
+    }
 
     m_tmpSetting.setPermissions(settings->permissions());
 
@@ -88,7 +97,7 @@ void ConnectionWidget::loadConfig(const NetworkManager::ConnectionSettings::Ptr
     const QStringList secondaries = settings->secondaries();
     const QStringList vpnKeys = vpnConnections().keys();
     if (!secondaries.isEmpty() && !vpnKeys.isEmpty()) {
-        Q_FOREACH(const QString & vpnKey, vpnKeys) {
+        Q_FOREACH (const QString & vpnKey, vpnKeys) {
             if (secondaries.contains(vpnKey)) {
                 m_widget->vpnCombobox->setCurrentIndex(m_widget->vpnCombobox->findData(vpnKey));
                 m_widget->autoconnectVpn->setChecked(true);
@@ -100,6 +109,12 @@ void ConnectionWidget::loadConfig(const NetworkManager::ConnectionSettings::Ptr
     }
 
     m_widget->autoconnect->setChecked(settings->autoconnect());
+
+#if NM_CHECK_VERSION(1, 0, 0)
+    if (m_widget->prioritySpin->isEnabled()) {
+        m_widget->prioritySpin->setValue(settings->autoconnectPriority());
+    }
+#endif
 }
 
 NMVariantMapMap ConnectionWidget::setting() const
@@ -130,6 +145,12 @@ NMVariantMapMap ConnectionWidget::setting() const
         settings.setZone(zone);
     }
 
+#if NM_CHECK_VERSION(1, 0, 0)
+    if (m_widget->prioritySpin->isEnabled()) {
+        settings.setAutoconnectPriority(m_widget->prioritySpin->value());
+    }
+#endif
+
     return settings.toMap();
 }
 
@@ -143,7 +164,6 @@ void ConnectionWidget::openAdvancedPermissions()
     QPointer<AdvancedPermissionsWidget> dialog = new AdvancedPermissionsWidget(m_tmpSetting.permissions(), this);
     dialog->setWindowTitle(i18nc("@title:window advanced permissions editor",
                                  "Advanced Permissions Editor"));
-
     if (dialog->exec() == QDialog::Accepted) {
         m_tmpSetting.setPermissions(dialog->currentUsers());
     }
@@ -155,7 +175,7 @@ NMStringMap ConnectionWidget::vpnConnections() const
     NetworkManager::Connection::List list = NetworkManager::listConnections();
     NMStringMap result;
 
-    Q_FOREACH(const NetworkManager::Connection::Ptr & conn, list) {
+    Q_FOREACH (const NetworkManager::Connection::Ptr & conn, list) {
         NetworkManager::ConnectionSettings::Ptr conSet = conn->settings();
         if (conSet->connectionType() == NetworkManager::ConnectionSettings::Vpn) {
             // qCDebug(PLASMA_NM) << "Found VPN" << conSet->id() << conSet->uuid();
